@@ -1,5 +1,5 @@
 `crps` <-
-function(fit, ensembleData, dates=NULL, nSamples=NULL, seed=NULL, ...) {
+function(fit, ensembleData, dates=NULL, ...) {
 #
 # copyright 2006-present, University of Washington. All rights reserved.
 # for terms of use, see the LICENSE file
